---------------------
PatchSet 6884 
Date: 2008/02/20 01:12:26
Author: amosjeffries
Branch: cleanup
Tag: (none) 
Log:
More .h dependency fixes.

Members: 
	include/strsep.h:1.2->1.2.44.1 
	include/strtoll.h:1.1->1.1.22.1 
	include/xusleep.h:1.1->1.1.44.1 

Index: squid3/include/strsep.h
===================================================================
RCS file: /cvsroot/squid-sf//squid3/include/strsep.h,v
retrieving revision 1.2
retrieving revision 1.2.44.1
diff -u -r1.2 -r1.2.44.1
--- squid3/include/strsep.h	5 Jul 2006 19:50:52 -0000	1.2
+++ squid3/include/strsep.h	20 Feb 2008 01:12:26 -0000	1.2.44.1
@@ -16,38 +16,43 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
  * USA.
  */
-
 #ifndef GNULIB_STRSEP_H_
 #define GNULIB_STRSEP_H_
 
+#include "config.h"
+
 #if HAVE_STRSEP
 
 /*
  * Get strsep() declaration.
  */
+#if HAVE_STRING_H
 #include <string.h>
+#endif
 
 #else
 
-/* Searches the next delimiter (char listed in DELIM) starting at *STRINGP.
-   If one is found, it is overwritten with a NUL, and *STRINGP is advanced
+/**
+\par
+   Searches the next delimiter (char listed in DELIM) starting at *STRINGP.
+   If one is found, it is overwritten with a NULL, and *STRINGP is advanced
    to point to the next char after it.  Otherwise, *STRINGP is set to NULL.
    If *STRINGP was already NULL, nothing happens.
    Returns the old value of *STRINGP.
-
+\par
    This is a variant of strtok() that is multithread-safe and supports
    empty fields.
 
-   Caveat: It modifies the original string.
-   Caveat: These functions cannot be used on constant strings.
-   Caveat: The identity of the delimiting character is lost.
-   Caveat: It doesn't work with multibyte strings unless all of the delimiter
-           characters are ASCII characters < 0x30.
+\note   Caveat: It modifies the original string.
+\note   Caveat: These functions cannot be used on constant strings.
+\note   Caveat: The identity of the delimiting character is lost.
+\note   Caveat: It doesn't work with multibyte strings unless all of the delimiter
+                characters are ASCII characters < 0x30.
 
-   See also strtok_r().  */
-
-SQUIDCEXTERN char *strsep (char **stringp, const char *delim);
+   See also strtok_r().
+ */
+SQUIDCEXTERN char *strsep(char **stringp, const char *delim);
 
-#endif
+#endif /* HAVE_STRSEP */
 
 #endif /* GNULIB_STRSEP_H_ */
Index: squid3/include/strtoll.h
===================================================================
RCS file: /cvsroot/squid-sf//squid3/include/strtoll.h,v
retrieving revision 1.1
retrieving revision 1.1.22.1
diff -u -r1.1 -r1.1.22.1
--- squid3/include/strtoll.h	17 Aug 2007 19:51:26 -0000	1.1
+++ squid3/include/strtoll.h	20 Feb 2008 01:12:26 -0000	1.1.22.1
@@ -1,19 +1,31 @@
+/*
+ * $Id: strtoll.h,v 1.1.22.1 2008/02/20 01:12:26 amosjeffries Exp $
+ */
+#ifndef _SQUIDINC_STRTOLL_H
+#define _SQUIDINC_STRTOLL_H
+
+#include "config.h"
+
 #if HAVE_STRTOLL
 
 /*
  * Get strtoll() declaration.
  */
+#if HAVE_STDLIB_H
 #include <stdlib.h>
+#endif
 
 #else
 
-/*
+/**
+ \par
  * Convert a string to a int64 integer.
- *
+ \par
  * Ignores `locale' stuff.  Assumes that the upper and lower case
  * alphabets and digits are each contiguous.
  */
+SQUIDCEXTERN int64_t strtoll(const char *nptr, char **endptr, int base);
 
-SQUIDCEXTERN int64_t strtoll (const char *nptr, char **endptr, int base);
+#endif /* !HAVE_STRTOLL */
 
-#endif
+#endif /* _SQUIDINC_STRTOLL_H */
Index: squid3/include/xusleep.h
===================================================================
RCS file: /cvsroot/squid-sf//squid3/include/xusleep.h,v
retrieving revision 1.1
retrieving revision 1.1.44.1
diff -u -r1.1 -r1.1.44.1
--- squid3/include/xusleep.h	24 Apr 2007 06:54:56 -0000	1.1
+++ squid3/include/xusleep.h	20 Feb 2008 01:12:26 -0000	1.1.44.1
@@ -1 +1,11 @@
+/*
+ * $Id: xusleep.h,v 1.1.44.1 2008/02/20 01:12:26 amosjeffries Exp $
+ */
+#ifndef _INC_XUSLEEP_H
+#define _INC_XUSLEEP_H
+
+#include "config.h"
+
 SQUIDCEXTERN int xusleep(unsigned int);
+
+#endif /* _INC_XUSLEEP_H */
